﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace OpenCDDrive
{
	static class Program
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		/// <param name="args">Command-line arguments</param>
		[STAThread]
		static void Main(string[] args)
		{
			// Needed to style dialog
			Application.EnableVisualStyles();
			Application.SetCompatibleTextRenderingDefault(false);

			if (ContainsFlag(args, "?"))
			{
				ShowHelp();
				return;
			}

			if (ContainsFlag(args, "c"))
			{
				// Close the CD Drive
				CDController.CloseCDDrive();
			}
			else // Any other arguments or no arguments
			{
				// Open the CD Drive
				CDController.OpenCDDrive();
			}
		}

		/// <summary>Shows help message</summary>
		private static void ShowHelp()
		{
			MessageBox.Show("OpenCDDrive [-o] [-c] [-?]\r\n\r\n-o (or no arguments) - Opens the CD drive\r\n-c - Closes the CD drive (if supported)\r\n-? - Displays this help dialog", "OpenCDDrive");
		}

		/// <summary>Determines if the command line contains the specified command</summary>
		/// <param name="args">Command-line arguments</param>
		/// <param name="flag">The command line argument for which to search - can be prefixed with a forward slash or a dash</param>
		/// <returns>True if command is in the list of arguments</returns>
		private static bool ContainsFlag(string[] args, string flag)
		{
			bool result = false;

			string commandWithDash = "-" + flag;
			string commandWithSlash = "/" + flag;

			result = args.Contains<string>(commandWithDash, StringComparer.InvariantCultureIgnoreCase) ||
					 args.Contains<string>(commandWithSlash, StringComparer.InvariantCultureIgnoreCase);

			return result;
		}
	}
}
